summaryrefslogtreecommitdiffstats
path: root/filesharing/advanced/kcm_sambaconf/sambashare.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /filesharing/advanced/kcm_sambaconf/sambashare.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'filesharing/advanced/kcm_sambaconf/sambashare.h')
-rw-r--r--filesharing/advanced/kcm_sambaconf/sambashare.h64
1 files changed, 32 insertions, 32 deletions
diff --git a/filesharing/advanced/kcm_sambaconf/sambashare.h b/filesharing/advanced/kcm_sambaconf/sambashare.h
index 78379dde..39107505 100644
--- a/filesharing/advanced/kcm_sambaconf/sambashare.h
+++ b/filesharing/advanced/kcm_sambaconf/sambashare.h
@@ -29,10 +29,10 @@
#ifndef SAMBASHARE_H
#define SAMBASHARE_H
-#include <qdict.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qptrlist.h>
+#include <tqdict.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqptrlist.h>
class SambaConfigFile;
class QStringList;
@@ -41,7 +41,7 @@ class QStringList;
* A class which represents a Samba share
* @author Jan Sch&auml;fer
**/
-class SambaShare :public QDict<QString>
+class SambaShare :public TQDict<TQString>
{
public:
@@ -54,12 +54,12 @@ public:
* Creates a new SambaShare with the given name
* @param name the name of the share
**/
- SambaShare(const QString & name, SambaConfigFile* sambaFile);
+ SambaShare(const TQString & name, SambaConfigFile* sambaFile);
/**
* Returns the name of the share
**/
- const QString& getName() const;
+ const TQString& getName() const;
/**
@@ -67,13 +67,13 @@ public:
* returns false if the name already exists and the testWetherExists
* parameter is set to true
**/
- bool setName(const QString & name, bool testWetherExists=true);
+ bool setName(const TQString & name, bool testWetherExists=true);
/**
* Tests wether or not the given option is supported by Samba.
* It does this by testing the output of testparm for this option
**/
- bool optionSupported(const QString & name);
+ bool optionSupported(const TQString & name);
/**
* Returns the value of the given parameter
@@ -83,7 +83,7 @@ public:
* @param gobalValue if the gobal value should be returend
* @param defaultValue if the default value should be returned or a null string
**/
- QString getValue(const QString & name, bool globalValue=true, bool defaultValue=true);
+ TQString getValue(const TQString & name, bool globalValue=true, bool defaultValue=true);
/**
* Same as above but for boolean parameters
@@ -91,12 +91,12 @@ public:
* because you can't distinguish an unset parameter
* from a false parameter
**/
- bool getBoolValue(const QString & name, bool globalValue=true, bool defaultValue=true);
+ bool getBoolValue(const TQString & name, bool globalValue=true, bool defaultValue=true);
/**
* Returns the value from the [globals] section
**/
- QString getGlobalValue(const QString & name, bool defaultValue=true);
+ TQString getGlobalValue(const TQString & name, bool defaultValue=true);
/**
* Sets the parameter name to the given value
@@ -108,70 +108,70 @@ public:
* exists and it it is different to it. If no global value exists then it is only
* set if different to the default value.
**/
- void setValue(const QString & name,const QString & value, bool globalValue=true, bool defaultValue=true);
+ void setValue(const TQString & name,const TQString & value, bool globalValue=true, bool defaultValue=true);
/**
* Same as above but for boolean parameters
**/
- void setValue(const QString & name, bool value, bool globalValue=true, bool defaultValue=true);
+ void setValue(const TQString & name, bool value, bool globalValue=true, bool defaultValue=true);
/**
* Same as above but for integer parameters
**/
- void setValue(const QString & name, int value, bool globalValue=true, bool defaultValue=true);
+ void setValue(const TQString & name, int value, bool globalValue=true, bool defaultValue=true);
/**
* Returns the default value of the parameter
* @param name the name of the parameter
**/
- QString getDefaultValue(const QString & name);
+ TQString getDefaultValue(const TQString & name);
/**
* Same as above but for booleans
**/
- bool getDefaultBoolValue(const QString & name);
+ bool getDefaultBoolValue(const TQString & name);
/**
* Returns the default synonym for the given parameter
* if no synonym exists the original parameter in lower
* case is returned
**/
- QString getSynonym(const QString & name) const;
+ TQString getSynonym(const TQString & name) const;
/**
* Returns the comments of the share
* e.g. the text above the [...] section
**/
- QStringList getComments();
+ TQStringList getComments();
/**
* Sets the comments for the share
* e.g. the text above the [...] section
**/
- void setComments(const QStringList & commentList);
+ void setComments(const TQStringList & commentList);
/**
* Sets the comments for the passed option
**/
- void setComments(const QString & name, const QStringList & commentList);
+ void setComments(const TQString & name, const TQStringList & commentList);
/**
* Returns the comments of the passed option
**/
- QStringList getComments(const QString & name);
+ TQStringList getComments(const TQString & name);
/**
* Returns true if the passed option has comments
* otherwise returns false
**/
- bool hasComments(const QString & name);
+ bool hasComments(const TQString & name);
/**
* Returns the list of all options
* the order of the options is exactly the
* order of the insertion of the options
**/
- QStringList getOptionList();
+ TQStringList getOptionList();
/**
* Returns true if this share is a printer
@@ -190,7 +190,7 @@ protected:
* The name of the share
* could be also printers, global and homes
**/
- QString _name;
+ TQString _name;
SambaConfigFile* _sambaFile;
/**
@@ -198,34 +198,34 @@ protected:
* the comments which stood above the option name
* are stored in this QStringList
**/
- QDict<QStringList> _commentList;
+ TQDict<TQStringList> _commentList;
/**
* The comments for this share
**/
- QStringList _comments;
+ TQStringList _comments;
/**
* An extra list which holds
* all stored options
* You might say, hey for what is this ?
* We have them already stored in the QDict.
* That's right, but there is a problem :
* QDict doesn't preserve the order of
* the inserted items, but when saving
* the options back to the smb.conf
* we want to have exactly the same order
* so this QStringList is only for saving
* the order of the options.
* On the other side we need a very fast lookup
* of the options, because we lookup very frequently
* so this is the best way to do both.
**/
- QStringList _optionList;
+ TQStringList _optionList;
};
-typedef QPtrList<SambaShare> SambaShareList;
+typedef TQPtrList<SambaShare> SambaShareList;
#endif
@@ -198,34 +198,34 @@ protected:
* all stored options
* You might say, hey for what is this ?
- * We have them already stored in the QDict.
+ * We have them already stored in the TQDict.
* That's right, but there is a problem :
@@ -198,34 +198,34 @@ protected:
* That's right, but there is a problem :
- * QDict doesn't preserve the order of
+ * TQDict doesn't preserve the order of
* the inserted items, but when saving
* the options back to the smb.conf
@@ -198,34 +198,34 @@ protected:
* the options back to the smb.conf
* we want to have exactly the same order
- * so this QStringList is only for saving
+ * so this TQStringList is only for saving
* the order of the options.
* On the other side we need a very fast lookup